@@ -11,8 +11,7 @@ from deskbar.ui.About import show_about
 from deskbar.ui.DeskbarPreferencesUI import show_preferences
 from deskbar.DeskbarAppletPreferences import DeskbarAppletPreferences
 from deskbar.Keybinder import get_deskbar_keybinder
-from deskbar.ui.cuemiac.Cuemiac import CuemiacUI
-from deskbar.ui.completion.CompletionDeskbarUI import CompletionDeskbarUI
+from deskbar.ui.cuemiac.CuemiacButtonUI import CuemiacButtonUI
 from deskbar.ui.entriac.CuemiacEntryUI import CuemiacEntryUI
 
 
@@ -40,6 +39,8 @@ class DeskbarApplet:
 		self.loader.connect ("module-stopped", self.module_list.module_toggled_cb)
 		self.loader.connect ("module-initialized", self._connect_if_async)
 
+		gtk.window_set_default_icon_name("deskbar-applet")
+		
 		# Set and retrieve the UI to be used
 		ui_name = deskbar.GCONF_CLIENT.get_string(self.prefs.GCONF_UI_NAME)
 		if ui_name == None:
@@ -49,14 +50,8 @@ class DeskbarApplet:
 		if deskbar.UI_OVERRIDE != None:
 			ui_name = deskbar.UI_OVERRIDE
 		
-		# Check for cairo otherwise cuemiac isn't available at all
-		if not hasattr(gtk.gdk.Drawable, 'cairo_create'):
-			ui_name = deskbar.COMPLETION_UI_NAME
-		
-		if ui_name == deskbar.COMPLETION_UI_NAME:
-			self.ui = CompletionDeskbarUI (applet, self.prefs)
-		elif ui_name == deskbar.CUEMIAC_UI_NAME:
-			self.ui = CuemiacUI (applet, self.prefs)
+		if ui_name == deskbar.CUEMIAC_UI_NAME:
+			self.ui = CuemiacButtonUI (applet, self.prefs)
 		elif ui_name == deskbar.ENTRIAC_UI_NAME:
 			self.ui = CuemiacEntryUI(applet, self.prefs)
 			
@@ -297,16 +292,10 @@ class DeskbarApplet:
 		
 		ui_name = value.get_string()
 
-		# Check for cairo otherwise cuemiac isn't available at all
-		if not hasattr(gtk.gdk.Drawable, 'cairo_create'):
-			ui_name = deskbar.COMPLETION_UI_NAME
-			
 		if ui_name == deskbar.CUEMIAC_UI_NAME:
-			self.ui = CuemiacUI (self.applet, self.prefs)
+			self.ui = CuemiacButtonUI (self.applet, self.prefs)
 		elif ui_name == deskbar.ENTRIAC_UI_NAME:
 			self.ui = CuemiacEntryUI(self.applet, self.prefs)
-		elif ui_name == deskbar.COMPLETION_UI_NAME:
-			self.ui = CompletionDeskbarUI (self.applet, self.prefs)
 		
 		self.set_up_ui_signals ()
 		self.applet.add (self.ui.get_view())
