@@ -14,12 +14,15 @@ class HistoryHandler(deskbar.Handler.Handler):
 	def __init__(self):
 		deskbar.Handler.Handler.__init__(self, "stock_redo")
 		
-	def query(self, query, max):
+	def query(self, query):
 		result = []
 		for text, match in get_deskbar_history():
 			if text.startswith(query):
 				match.get_category = lambda: "history"
-				match._history_priority = self.get_priority()
+				
+				# Beware of the infinite recursion here !
+				match_prio = match.get_priority()[1]
+				match.get_priority = lambda: (self.get_priority(), match_prio)
 				result.append((text, match))
 		
 		return result
